'
' SAS Data Quality Set SSL Utility
'
' Copyright (c) 2020 SAS Institute Inc.
'

' constants from MSDN
Const ForReading = 1
Const ForWriting = 2

' usage strings
usage = "usage: set_ssl {1.0|1.1}"
version = "Data Quality Set SSL Utility version 1.0"

' command line or GUI? 
If InStr(UCase(WScript.FullName), "CSCRIPT") Then
    isGUI = false
Else
    isGUI = true
End If

' show a message to the user
Sub ShowMessage(msg, msgType)
    If isGUI Then
        Call MsgBox(msg, vbOKOnly + msgType, "Set SSL")
    Else
        WScript.Echo(msg)
    End If
End Sub
Sub ShowInfo(msg)
    Call ShowMessage(msg, vbInformation)
End Sub
Sub ShowError(msg)
    Call ShowMessage(msg, vbExclamation)
End Sub

' process command line
If WScript.Arguments.Count < 1 Then
    WScript.Echo usage
    WScript.Quit 1
End If

srcDLL = "[error]"

param = WScript.Arguments(0)
If param = "--help" Then
    WScript.Echo usage
    WScript.Quit 0
ElseIf param = "--version" Then
    WScript.Echo version
    WScript.Quit 0
ElseIf param = "1.0" Then
    srcDLL = "gsoap_ssl10x.dll"
ElseIf param = "1.1" Then
    srcDLL = "gsoap_ssl11x.dll"
Else
    WScript.Echo usage
    WScript.Quit 1
End If

' find current path. go up a folder level
Set fso = CreateObject("Scripting.FileSystemObject")
bindir = fso.GetFile(WScript.ScriptFullName).ParentFolder.ParentFolder

' binaries are in sasexe
bindir = bindir & "\sasexe"

targetDLL = "gsoap_ssl.dll"

On Error Resume Next
fso.CopyFile bindir & "\" & srcDLL, bindir & "\" & targetDLL, True

If Err Then
    ShowError "Could not update " & targetDLL & ": " & Err.Description
Else
    ShowInfo "Updated SSL libraries (" & param & ")"
End If
On Error Goto 0

